#!/bin/env perl

use strict;
use warnings;
use feature ':5.10';
use mro 'c3';

use Text::CSV;
use Text::CSV::Slurp;
use Manalink::CSV;

my $csv = Text::CSV->new({ binary=>1, eol=>"\r\n", sep_char=>';', quote_space=>0, allow_whitespace=>1, quote_binary=>0, auto_diag=>1 }) or die "Couldn't create Text::CSV: " . Text::CSV->error_diag();

say "Reading Manalink.csv";
my $manalink = Text::CSV::Slurp->load(file => 'Manalink.csv', sep_char=>';');

say "Reading ct_all.csv";
my $ct_all = Text::CSV::Slurp->load(file => 'ct_all.csv', sep_char=>';');

my %manalink_names;
foreach my $ml (@$manalink)
  {
    $manalink_names{$ml->{'Full Name'}} = $ml;
  }

say "";

my @ct_columns = ct_hdrs();

my $outfilename = 'ct_plus_rulestext.csv';
open(my $outfile, '>', $outfilename) or die "Couldn't open $outfilename: $!";

{
  my @hdrs = @ct_columns;
  push @hdrs, 'Rules Text';
  $csv->combine(@hdrs) or die qq[Couldn't combine csv fields for headers line: ] . Text::CSV->error_diag();
  print $outfile $csv->string();
}

foreach my $ct (@$ct_all)
  {
    $ct->{'Sort order'} eq '#' and next;
    my $nam = name $ct;
    $nam =~ /^#/ and next;

    my $ml = $manalink_names{$nam};
    if (!defined $ml)
      {
	say "\nCouldn't find \$manalink_names{'$nam'}";
	next;
      }

    my @r;
    foreach my $c (@ct_columns)
      {
	push @r, $ct->{$c};
      }
    push @r, $ml->{'Rules Text'};

    $csv->combine(@r) or die qq[Couldn't combine csv fields for card $nam: ] . Text::CSV->error_diag();
    print $outfile $csv->string();
  }
close $outfile;
